
import setuptools

setuptools.setup(
    name='kobebatman',
    version=1.0,
    long_description='Энэ package нь ийм ийм юм хийх зориулалттай',
    packages=setuptools.find_packages(exclude=['test', 'data'])
)